@@ -16,12 +16,15 @@ the traceback to stdout, and keep any assertions you have from running
 be of further significance to your tests).
 """
 
-import os, sys, time, re
-import types
-import pprint
-import socket
 import httplib
+import os
+import pprint
+import re
+import socket
+import sys
+import time
 import traceback
+import types
 
 from unittest import *
 from unittest import _TextTestResult
@@ -48,9 +51,7 @@ class TerseTestRunner(TextTestRunner):
         "Run the given test case or test suite."
         # Overridden to remove unnecessary empty lines and separators
         result = self._makeResult()
-        startTime = time.time()
         test(result)
-        timeTaken = float(time.time() - startTime)
         result.printErrors()
         if not result.wasSuccessful():
             self.stream.write("FAILED (")
@@ -142,6 +143,14 @@ class WebCase(TestCase):
     HTTP_CONN = httplib.HTTPConnection
     PROTOCOL = "HTTP/1.1"
     
+    scheme = "http"
+    url = None
+    
+    status = None
+    headers = None
+    body = None
+    time = None
+    
     def set_persistent(self, on=True, auto_open=False):
         """Make our HTTP_CONN persistent (or not).
         
@@ -164,10 +173,12 @@ class WebCase(TestCase):
         
         if on:
             host = self.HOST
-            if not host:
-                # The empty string signifies INADDR_ANY,
-                # which should respond on localhost.
+            if host == '0.0.0.0':
+                # INADDR_ANY, which should respond on localhost.
                 host = "127.0.0.1"
+            elif host == '::':
+                # IN6ADDR_ANY, which should respond on localhost.
+                host = "::1"
             self.HTTP_CONN = cls(host, self.PORT)
             # Automatically re-connect?
             self.HTTP_CONN.auto_open = auto_open
@@ -177,7 +188,7 @@ class WebCase(TestCase):
     
     def _get_persistent(self):
         return hasattr(self.HTTP_CONN, "__class__")
-    def _set_persistent(self, on=True):
+    def _set_persistent(self, on):
         self.set_persistent(on)
     persistent = property(_get_persistent, _set_persistent)
     
@@ -186,13 +197,11 @@ class WebCase(TestCase):
         ServerError.on = False
         
         self.url = url
-        host = self.HOST
-        if not host:
-            # The empty string signifies INADDR_ANY,
-            # which should respond on localhost.
-            host = "127.0.0.1"
-        result = openURL(url, headers, method, body, host, self.PORT,
+        self.time = None
+        start = time.time()
+        result = openURL(url, headers, method, body, self.HOST, self.PORT,
                          self.HTTP_CONN, protocol or self.PROTOCOL)
+        self.time = time.time() - start
         self.status, self.headers, self.body = result
         
         # Build a list of request cookies from the previous response cookies.
@@ -329,13 +338,13 @@ class WebCase(TestCase):
         if isinstance(status, basestring):
             if not self.status == status:
                 if msg is None:
-                    msg = 'Status (%s) != %s' % (`self.status`, `status`)
+                    msg = 'Status (%r) != %r' % (self.status, status)
                 self._handlewebError(msg)
         elif isinstance(status, int):
             code = int(self.status[:3])
             if code != status:
                 if msg is None:
-                    msg = 'Status (%s) != %s' % (`self.status`, `status`)
+                    msg = 'Status (%r) != %r' % (self.status, status)
                 self._handlewebError(msg)
         else:
             # status is a tuple or list.
@@ -350,7 +359,7 @@ class WebCase(TestCase):
                     break
             if not match:
                 if msg is None:
-                    msg = 'Status (%s) not in %s' % (`self.status`, `status`)
+                    msg = 'Status (%r) not in %r' % (self.status, status)
                 self._handlewebError(msg)
     
     def assertHeader(self, key, value=None, msg=None):
@@ -363,9 +372,9 @@ class WebCase(TestCase):
         
         if msg is None:
             if value is None:
-                msg = '%s not in headers' % `key`
+                msg = '%r not in headers' % key
             else:
-                msg = '%s:%s not in headers' % (`key`, `value`)
+                msg = '%r:%r not in headers' % (key, value)
         self._handlewebError(msg)
     
     def assertNoHeader(self, key, msg=None):
@@ -374,35 +383,35 @@ class WebCase(TestCase):
         matches = [k for k, v in self.headers if k.lower() == lowkey]
         if matches:
             if msg is None:
-                msg = '%s in headers' % `key`
+                msg = '%r in headers' % key
             self._handlewebError(msg)
     
     def assertBody(self, value, msg=None):
         """Fail if value != self.body."""
         if value != self.body:
             if msg is None:
-                msg = 'expected body:\n%s\n\nactual body:\n%s' % (`value`, `self.body`)
+                msg = 'expected body:\n%r\n\nactual body:\n%r' % (value, self.body)
             self._handlewebError(msg)
     
     def assertInBody(self, value, msg=None):
         """Fail if value not in self.body."""
         if value not in self.body:
             if msg is None:
-                msg = '%s not in body' % `value`
+                msg = '%r not in body' % value
             self._handlewebError(msg)
     
     def assertNotInBody(self, value, msg=None):
         """Fail if value in self.body."""
         if value in self.body:
             if msg is None:
-                msg = '%s found in body' % `value`
+                msg = '%r found in body' % value
             self._handlewebError(msg)
     
     def assertMatchesBody(self, pattern, msg=None, flags=0):
         """Fail if value (a regex pattern) is not in self.body."""
         if re.search(pattern, self.body, flags) is None:
             if msg is None:
-                msg = 'No match for %s in body' % `pattern`
+                msg = 'No match for %r in body' % pattern
             self._handlewebError(msg)
 
 
@@ -475,6 +484,12 @@ def openURL(url, headers=None, method="GET", body=None,
             if hasattr(http_conn, "host"):
                 conn = http_conn
             else:
+                if host == '0.0.0.0':
+                    # INADDR_ANY, which should respond on localhost.
+                    host = "127.0.0.1"
+                elif host == '::':
+                    # IN6ADDR_ANY, which should respond on localhost.
+                    host = "::1"
                 conn = http_conn(host, port)
             
             conn._http_vsn_str = protocol
